darkhistory.electrons.ics.ics\_spectrum
=======================================

.. automodule:: darkhistory.electrons.ics.ics_spectrum

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: ics_spectrum
   
      ics_spec
      thomson_spec_series
      thomson_spec_diff
      thomson_spec
      thomson_spec_quad
      rel_spec
   
   

   
   
   

   
   
   